; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = 
a = a
b = b
c = 
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Super Motions |--------------------------------------------------------

;-| Special Motions |------------------------------------------------------
[Command]
name = "Super 3 (Dragon Knuckler)"
command = ~D, DF, F, D, DF, F, x
time = 35

[Command]
name = "Super 3 (Dragon Knuckler)"
command = D, F, D, F, x
time = 35

[Command]
name = "Super 1 (Lunar Blade)"
command = ~D, DB, B, D, DB, B, a
time = 35

[Command]
name = "Super 1 (Lunar Blade)"
command = D,B,D,B,a
time = 35

[Command]
name = "Super 2 (Triple Combo)"
command = B,F,B,F,b
time = 35


[Command]
name = "Special 3 (Dragon Kick)"
command = B, F, b
time = 20

[Command]
name = "Special 2 (Crescent Moon)"
command = B, D, B, a
time = 20

[Command]
name = "Special 2 (Crescent Moon)"
command = ~B, DB, D, DB, B, a
time = 20


[Command]
name = "Special 1 (Dragon Combo)"
command = ~D, DF, F, x
time = 25

[Command]
name = "Special 1 (Dragon Combo)"
command = D, F, x
time = 25


[Command]
name = "Evade"
command = B, F, y
time = 20

[Command]
name = "Evade"
command = F, B, y
time = 20


[Command]
name = "Grab 1"
command = /F, x+y
time = 20


[Command]
name = "Grab 1"
command = /F, x+y
time = 20

[Command]
name = "Grab 2"
command = /F, a+b
time = 20

[Command]
name = "-> Jump Front Kick"     ;Required (do not remove)
command = /F, a
time = 10

[Command]
name = "-> Jump Front Kick"     ;Required (do not remove)
command = /UF, a
time = 10

[Command]
name = "<- Jump Front Kick"     ;Required (do not remove)
command = /B, a
time = 10

[Command]
name = "<- Jump Front Kick"     ;Required (do not remove)
command = /UB, a
time = 10

[Command]
name = "-> Jump Back Kick"     ;Required (do not remove)
command = /F, b
time = 10
[Command]
name = "-> Jump Back Kick"     ;Required (do not remove)
command = /UF, b
time = 10

[Command]
name = "<- Jump Back Kick"     ;Required (do not remove)
command = /B, b
time = 10

[Command]
name = "<- Jump Back Kick"     ;Required (do not remove)
command = /UB, b
time = 10


[Command]
name = "-> Crouch Front Punch"     ;Required (do not remove)
command = /$DF, x
time = 10

[Command]
name = "<- Crouch Front Punch"     ;Required (do not remove)
command = /$DB, x
time = 10

[Command]
name = "-> Crouch Back Punch"     ;Required (do not remove)
command = /$DF, y
time = 10

[Command]
name = "<- Crouch Back Punch"     ;Required (do not remove)
command = /$DB, y
time = 10

[Command]
name = "-> Crouch Front Kick"     ;Required (do not remove)
command = /$DF, a
time = 10

[Command]
name = "<- Crouch Front Kick"     ;Required (do not remove)
command = /$DB, a
time = 10

[Command]
name = "-> Crouch Back Kick"     ;Required (do not remove)
command = /$DF, b
time = 10

[Command]
name = "<- Crouch Back Kick"     ;Required (do not remove)
command = /$DB, b
time = 10

[Command]
name = "-> Front Punch"
command = /F, x
time = 10

[Command]
name = "<- Front Punch"
command = /B, x
time = 10

[Command]
name = "-> Back Punch"
command = /F, y
time = 10

[Command]
name = "<- Back Punch"
command = /B, y
time = 10

[Command]
name = "-> Front Kick"
command = /F, a
time = 10

[Command]
name = "<- Front Kick"
command = /B, a
time = 10

[Command]
name = "-> Back Kick"
command = /F, b
time = 10

[Command]
name = "<- Back Kick"
command = /B, b
time = 10
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------
[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;---------------------------------------------------------------------------
[State -1, AI ON]  ; Turn the AI on when
Type = VarSet
TriggerAll = Var(59) < 1 ; it is not on yet and
TriggerAll = RoundState=2 ; the fight has started and is not over yet and
Trigger1 = AILevel>0 ; the computer is playing the character
v = 59
value= 1 ; value of 1 will mean the AI is on
Ignorehitpause=1

[State -1, AI OFF] ; Turn the AI off when
Type=VarSet
Trigger1=var(59)>0  ; it is on and
Trigger1=RoundState!=2  ; the round is not started yet or is already over
Trigger2=!IsHelper  ; OR if we are a player, but
Trigger2=AILevel=0  ; the computer is not in control
v=59
value=0 ; value of 0 will mean the AI is off. values other than 0 and 1 are not used in this example, we have only one AI mode, the normal one.
Ignorehitpause=1

[State -1]
Type=VarSet
Trigger1=1
var(50)=(AILevel=1)*3+(AILevel=2)*7+(AILevel=3)*16+(AILevel=4)*30+(AILevel=5)*58+(AILevel=6)*90+ (AILevel=7)*150+(AILevel=8)*300

[State -1]
Type=Changestate
Triggerall=Inguarddist ; Guard when in guard distance
Triggerall=var(59)>0 ; and the AI is on
Triggerall=ctrl ; and we have control
Trigger1 = random< (var(50)*2+(AiLevel>=3)*10) ; chance is higher than for attacking, but not by too much. 
value=120

[State -1] ; The engine will still guard by through pressing the back button, we need to disable that.
Type=Assertspecial
Triggerall=StateNo!=[120,160]
Trigger1=var(59)>0
flag=noairguard
flag2=nocrouchguard
flag3=nostandguard

;===========================================================================
;---------------------------------------------------------------------------
[State -1, Super 3 (Dragon Knuckler)]
type = ChangeState
value = 1520
Triggerall=var(59)=0
triggerall = command = "Super 3 (Dragon Knuckler)"
triggerall = power >= 3000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1410 && time > 12) && movecontact

[State -1, Super 3 (Dragon Knuckler)) AI]
type = ChangeState
value = 1520
Triggerall=var(59)>0 
triggerall = !Win
Triggerall=random<= AIlevel*12
triggerall = power >= 3000
Triggerall=!Inguarddist
triggerall = statetype != A
triggerall = P2bodydist X = [0,11] 
triggerall = P2Statetype != L
triggerall = p2Statetype != A
Triggerall=AILevel>= 5
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1410 && time > 12) && movecontact

[State -1, Super 2 (Triple Combo)]
type = ChangeState
value = 1510
Triggerall=var(59)=0
triggerall = command = "Super 2 (Triple Combo)"
triggerall = power >= 2000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact

[State -1, Super 2 (Triple Combo) AI]
type = ChangeState
value = 1510
Triggerall=var(59)>0 
triggerall = !Win
Triggerall=random<= AIlevel*10
triggerall = power >= 2000
Triggerall=!Inguarddist
triggerall = statetype != A
triggerall = P2bodydist X = [0,30] 
triggerall = P2Statetype != L
triggerall = p2Statetype != A
Triggerall=AILevel>= 5
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact

[State -1, Super 1 (Lunar Blade)]
type = ChangeState
value = 1500
Triggerall=var(59)=0
triggerall = command = "Super 1 (Lunar Blade)"
triggerall = power >= 1000
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1410 && time > 12) && movecontact

[State -1, Super 1 (Lunar Blade) AI]
type = ChangeState
value = 1500
Triggerall=var(59)>0 
triggerall = !Win
Triggerall=random<= AIlevel*3
triggerall = power >= 1000
Triggerall=!Inguarddist
triggerall = statetype != A
triggerall = P2bodydist X = [0,30] 
triggerall = P2Statetype != L
triggerall = p2Statetype != A
Triggerall=AILevel>= 5
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1410 && time > 12) && movecontact


[State -1, Special 3 (Dragon Kick)]
type = ChangeState
value = 1410
Triggerall=var(59)=0
triggerall = command = "Special 3 (Dragon Kick)"
triggerall = statetype = S
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 18 || stateno = 1040 && time > 15 || stateno = 1050 && time > 15 || stateno = 1060 && time > 24 || stateno = 1070 && time > 15) && movecontact
trigger5 = (stateno = 1300 && time > 45 || stateno = 1310 && time > 50) && movecontact


[State -1, Special 3 (Dragon Kick) AI]
type = ChangeState
value = 1410
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*5
triggerall = statetype = S
Triggerall=!Inguarddist
triggerall = P2BodyDist X = [0,35] 
triggerall = p2statetype != L
triggerall = statetype = S
trigger1 = ctrl
Triggerall=AILevel>= 5
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 18 || stateno = 1040 && time > 15 || stateno = 1050 && time > 15 || stateno = 1060 && time > 24 || stateno = 1070 && time > 15) && movecontact
trigger5 = (stateno = 1300 && time > 45 || stateno = 1310 && time > 50) && movecontact

[State -1, Special 2 (Crescent Moon)]
type = ChangeState
value = 1420
Triggerall=var(59)=0
triggerall = command = "Special 2 (Crescent Moon)"
triggerall = statetype = S
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 18 || stateno = 1040 && time > 15 || stateno = 1050 && time > 15 || stateno = 1060 && time > 24 || stateno = 1070 && time > 15) && movecontact
trigger5 = (stateno = 1300 && time > 45 || stateno = 1310 && time > 50) && movecontact


[State -1, Special 2 (Crescent Moon)) AI]
type = ChangeState
value = 1420
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*5
triggerall = statetype = S
Triggerall=!Inguarddist
triggerall = P2BodyDist X = [0,15] 
triggerall = p2statetype != L
triggerall = statetype = S
trigger1 = ctrl
Triggerall=AILevel>= 5
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 18 || stateno = 1040 && time > 15 || stateno = 1050 && time > 15 || stateno = 1060 && time > 24 || stateno = 1070 && time > 15) && movecontact
trigger5 = (stateno = 1300 && time > 45 || stateno = 1310 && time > 50) && movecontact


[State -1, Special 1 (Dragon Combo)]
type = ChangeState
value = 1400
Triggerall=var(59)=0
triggerall = command = "Special 1 (Dragon Combo)"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 18 || stateno = 1040 && time > 15 || stateno = 1050 && time > 15 || stateno = 1060 && time > 24 || stateno = 1070 && time > 15) && movecontact
trigger5 = (stateno = 1300 && time > 45 || stateno = 1310 && time > 50) && movecontact

[State -1, Special 1 (Dragon Combo) AI]
type = ChangeState
value = 1400
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*5
triggerall = statetype = S
Triggerall=!Inguarddist
triggerall = P2BodyDist X = [0,25] 
triggerall = p2statetype != L
triggerall = statetype = S
trigger1 = ctrl
Triggerall=AILevel>= 5
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && (movecontact)
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 18 || stateno = 1040 && time > 15 || stateno = 1050 && time > 15 || stateno = 1060 && time > 15 || stateno = 1070 && time > 15) && movecontact

[State -1, Special 1 (Dragon Combo 1) AI]
type = ChangeState
value = 1401
Triggerall = stateno = 1400
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*5
triggerall = statetype = S
Triggerall=!Inguarddist
triggerall = P2BodyDist X = [0,25] 
triggerall = p2statetype != L
triggerall = statetype = S
trigger1 = ctrl
Triggerall=AILevel>= 5

[State -1, Special 1 (Dragon Combo 2) AI]
type = ChangeState
value = 1402
Triggerall = stateno = 1401
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*5
triggerall = statetype = S
Triggerall=!Inguarddist
triggerall = P2BodyDist X = [0,25] 
triggerall = p2statetype != L
triggerall = statetype = S
trigger1 = ctrl
Triggerall=AILevel>= 5





[State -1, Evade]
type = ChangeState
value = 1300
Triggerall=var(59)=0
triggerall = (Command = "Evade")
trigger1 = (StateType = S) && (Ctrl)
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 10 || stateno = 1010 && time > 10 || stateno = 1020 && time > 10 || stateno = 1030 && time > 10 || stateno = 1040 && time > 10 || stateno = 1050 && time > 10 || stateno = 1060 && time > 10 || stateno = 1070 && time > 10) && movecontact


; Evade
[State -1, Evade AI]
type = ChangeState
value = 1300
Triggerall=var(59)>0
triggerall =  !Win
Triggerall=!Inguarddist
triggerall = statetype != A
Triggerall=random<= AIlevel*3
Triggerall = p2bodydist x >= 120
Triggerall=AILevel>= 4
trigger1 = (StateType = S) && (Ctrl)
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 10 || stateno = 1010 && time > 10 || stateno = 1020 && time > 10 || stateno = 1030 && time > 10 || stateno = 1040 && time > 10 || stateno = 1050 && time > 10 || stateno = 1060 && time > 10 || stateno = 1070 && time > 10) && movecontact



[State -1, Grab 1]
type = ChangeState
value = 1200
Triggerall=var(59)=0
triggerall = command = "Grab 1"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 10 || stateno = 1010 && time > 10 || stateno = 1020 && time > 10 || stateno = 1030 && time > 10 || stateno = 1040 && time > 10 || stateno = 1050 && time > 10 || stateno = 1060 && time > 10 || stateno = 1070 && time > 10) && movecontact


[State -1, Grab 1 AI]
type = ChangeState
value = 1200
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*3
triggerall = statetype = S
Triggerall=!Inguarddist
triggerall = P2BodyDist X = [0,25] 
triggerall = p2statetype != L
triggerall = statetype = S
trigger1 = ctrl
Triggerall=AILevel>= 3
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 10 || stateno = 1010 && time > 10 || stateno = 1020 && time > 10 || stateno = 1030 && time > 10 || stateno = 1040 && time > 10 || stateno = 1050 && time > 10 || stateno = 1060 && time > 10 || stateno = 1070 && time > 10) && movecontact


[State -1, Grab 2]
type = ChangeState
value = 1210
Triggerall=var(59)=0
triggerall = command = "Grab 2"
triggerall = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 10 || stateno = 1010 && time > 10 || stateno = 1020 && time > 10 || stateno = 1030 && time > 10 || stateno = 1040 && time > 10 || stateno = 1050 && time > 10 || stateno = 1060 && time > 10 || stateno = 1070 && time > 10) && movecontact


[State -1, Grab 2 AI]
type = ChangeState
value = 1210
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*3
triggerall = statetype = S
Triggerall=!Inguarddist
triggerall = P2BodyDist X = [0,25] 
triggerall = p2statetype != L
triggerall = statetype = S
trigger1 = ctrl
Triggerall=AILevel>= 3
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 10 || stateno = 1010 && time > 10 || stateno = 1020 && time > 10 || stateno = 1030 && time > 10 || stateno = 1040 && time > 10 || stateno = 1050 && time > 10 || stateno = 1060 && time > 10 || stateno = 1070 && time > 10) && movecontact



[State -1, -> Jump Front Kick]
type = ChangeState
value = 1100
Triggerall=var(59)=0
triggerall = command = "-> Jump Front Kick"
trigger1 = statetype = A
triggerall = statetype != S
triggerall = statetype != C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact

[State -1, -> Jump Front Kick AI]
type = ChangeState
value = 1100
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact



[State -1, <- Jump Front Kick]
type = ChangeState
value = 1110
Triggerall=var(59)=0
triggerall = command = "<- Jump Front Kick"
trigger1 = statetype = A
triggerall = statetype != S
triggerall = statetype != C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact

[State -1, <- Jump Front Kick AI]
type = ChangeState
value = 1110
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact


[State -1, -> Jump Back Kick]
type = ChangeState
value = 1120
Triggerall=var(59)=0
triggerall = command = "-> Jump Back Kick"
trigger1 = statetype = A
triggerall = statetype != S
triggerall = statetype != C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact

[State -1, -> Jump Back Kick AI]
type = ChangeState
value = 1120
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact

[State -1, <- Jump Back Kick]
type = ChangeState
value = 1130
Triggerall=var(59)=0
triggerall = command = "<- Jump Back Kick"
trigger1 = statetype = A
triggerall = statetype != S
triggerall = statetype != C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact

[State -1, <- Jump Back Kick AI]
type = ChangeState
value = 1130
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 600 || stateno = 610  && time > 15 || stateno = 630 || stateno = 640) && movecontact
trigger4 = (stateno = 1100 && time > 10|| stateno = 1110 && time > 10 || stateno = 1120 && time > 10 || stateno = 1130 && time > 10) && movecontact



[State -1, -> Crouch Front Punch]
type = ChangeState
value = 1000
Triggerall=var(59)=0
triggerall = command = "-> Crouch Front Punch"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, -> Crouch Front Punch AI]
type = ChangeState
value = 1000
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



[State -1, <- Crouch Front Punch]
type = ChangeState
value = 1010
Triggerall=var(59)=0
triggerall = command = "<- Crouch Front Punch"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact




[State -1, <- Crouch Front Punch AI]
type = ChangeState
value = 1010
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*1.3
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



[State -1, -> Crouch Back Punch]
type = ChangeState
value = 1020
Triggerall=var(59)=0
triggerall = command = "-> Crouch Back Punch"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact




[State -1, -> Crouch Back Punch AI]
type = ChangeState
value = 1020
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*1.3
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Crouch Back Punch]
type = ChangeState
value = 1030
Triggerall=var(59)=0
triggerall = command = "<- Crouch Back Punch"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact




[State -1, <- Crouch Back Punch AI]
type = ChangeState
value = 1030
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*1.3
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



[State -1, -> Crouch Front Kick]
type = ChangeState
value = 1040
Triggerall=var(59)=0
triggerall = command = "-> Crouch Front Kick"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact




[State -1, -> Crouch Front Kick AI]
type = ChangeState
value = 1040
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*1.3
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Crouch Front Kick]
type = ChangeState
value = 1050
Triggerall=var(59)=0
triggerall = command = "<- Crouch Front Kick"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact




[State -1, <- Crouch Front Kick AI]
type = ChangeState
value = 1050
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*1.3
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, -> Crouch Back Kick]
type = ChangeState
value = 1060
Triggerall=var(59)=0
triggerall = command = "-> Crouch Back Kick"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact




[State -1, -> Crouch Back Kick AI]
type = ChangeState
value = 1060
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*1.3
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Crouch Back Kick]
type = ChangeState
value = 1070
Triggerall=var(59)=0
triggerall = command = "<- Crouch Back Kick"
trigger1 = statetype = C
triggerall = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact




[State -1, <- Crouch Back Kick AI]
type = ChangeState
value = 1070
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*1.3
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 15 || stateno = 910 && time > 15 || stateno = 920 && time > 15 || stateno = 930 && time > 15 || stateno = 940 && time > 15 || stateno = 950 && time > 15 || stateno = 960 && time > 15 || stateno = 970 && time > 15) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact






[State -1, -> Front Punch]
type = ChangeState
value = 900
Triggerall=var(59)=0
triggerall = command = "-> Front Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



[State -1, -> Front Punch AI]
type = ChangeState
value = 900
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Front Punch]
type = ChangeState
value = 910
Triggerall=var(59)=0
triggerall = command = "<- Front Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Front Punch AI]
type = ChangeState
value = 910
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, -> Back Punch]
type = ChangeState
value = 920
Triggerall=var(59)=0
triggerall = command = "-> Back Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



[State -1, -> Back Punch AI]
type = ChangeState
value = 920
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Back Punch]
type = ChangeState
value = 930
Triggerall=var(59)=0
triggerall = command = "<- Back Punch"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Back Punch AI]
type = ChangeState
value = 930
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



[State -1, -> Front Kick]
type = ChangeState
value = 940
Triggerall=var(59)=0
triggerall = command = "-> Front Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, -> Front Kick AI]
type = ChangeState
value = 940
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Front Kick]
type = ChangeState
value = 950
Triggerall=var(59)=0
triggerall = command = "<- Front Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Front Kick AI]
type = ChangeState
value = 950
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, -> Back Kick]
type = ChangeState
value = 960
Triggerall=var(59)=0
triggerall = command = "-> Back Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, -> Back Kick AI]
type = ChangeState
value = 960
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



[State -1, <- Back Kick]
type = ChangeState
value = 970
Triggerall=var(59)=0
triggerall = command = "<- Back Kick"
trigger1 = statetype != A
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, <- Back Kick AI]
type = ChangeState
value = 970
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*7
Triggerall=!Inguarddist
triggerall = P2bodydist X = [0,20]
triggerall = P2StateType != L
trigger1 = statetype != A
Triggerall=AILevel>=1
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact










; Run Fwd
[State -1, Run Fwd]
type = ChangeState
Triggerall=var(59)=0
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl

;---------------------------------------------------------------------------
; Run Back
[State -1, Run Back]
type = ChangeState
Triggerall=var(59)=0
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl

;===========================================================================
;---------------------------------------------------------------------------
; Taunt
[State -1, Taunt]
type = ChangeState
value = 195
Triggerall=var(59)=0
triggerall = command = "s"
trigger1 = statetype != A
trigger1 = ctrl

;---------------------------------------------------------------------------
; Stand Light Punch
[State -1, Stand Light Punch]
type = ChangeState
value = 200
Triggerall=var(59)=0
triggerall = command = "x"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, Stand Light Punch AI]
type = ChangeState
value = 200
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

;---------------------------------------------------------------------------
; Stand Medium Punch
[State -1, Stand Medium Punch]
type = ChangeState
value = 210
Triggerall=var(59)=0
triggerall = command = "y"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

[State -1, Stand Medium Punch AI]
type = ChangeState
value = 210
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

;---------------------------------------------------------------------------
; Stand Light Kick
[State -1, Stand Light Kick]
type = ChangeState
value = 230
Triggerall=var(59)=0
triggerall = command = "a"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

[State -1, Stand Light Kick AI]
type = ChangeState
value = 230
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

;---------------------------------------------------------------------------
; Standing Medium Kick
[State -1, Standing Medium Kick]
type = ChangeState
value = 240
Triggerall=var(59)=0
triggerall = command = "b"
triggerall = command != "holddown"
trigger1 = statetype = S
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

[State -1, Standing Medium Kick AI]
type = ChangeState
value = 240
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


;---------------------------------------------------------------------------
; Crouching Light Punch
[State -1, Crouching Light Punch]
type = ChangeState
value = 400
Triggerall=var(59)=0
triggerall = command = "x"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

[State -1, Crouching Light Punch AI]
type = ChangeState
value = 400
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

;---------------------------------------------------------------------------
; Crouching Medium Punch
[State -1, Crouching Medium Punch]
type = ChangeState
value = 410
Triggerall=var(59)=0
triggerall = command = "y"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 && time > 15 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


[State -1, Crouching Medium Punch AI]
type = ChangeState
value = 410
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 && time > 15 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact



;---------------------------------------------------------------------------
; Crouching Light Kick
[State -1, Crouching Light Kick]
type = ChangeState
value = 430
Triggerall=var(59)=0
triggerall = command = "a"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 && time > 15 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

; Crouching Light Kick
[State -1, Crouching Light Kick AI]
type = ChangeState
value = 430
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 && time > 15 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

;---------------------------------------------------------------------------
; Crouching Medium Kick
[State -1, Crouching Medium Kick]
type = ChangeState
value = 440
Triggerall=var(59)=0
triggerall = command = "b"
triggerall = command = "holddown"
trigger1 = statetype = C
trigger1 = ctrl
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 && time > 15 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact

; Crouching Medium Kick
[State -1, Crouching Medium Kick AI]
type = ChangeState
value = 440
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<= AIlevel*6.2
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
Triggerall=!Inguarddist
trigger1 = statetype = S
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 200 || stateno = 210 || stateno = 230 || stateno = 240 || stateno = 400 || stateno = 410 && time > 15 || stateno = 430 || stateno = 440) && movecontact
trigger3 = (stateno = 900 && time > 12 || stateno = 910 && time > 15 || stateno = 920 && time > 16 || stateno = 930 && time > 19 || stateno = 940 && time > 18 || stateno = 950 && time > 18 || stateno = 960 && time > 15 || stateno = 970 && time > 25) && movecontact
trigger4 = (stateno = 1000 && time > 14 || stateno = 1010 && time > 14 || stateno = 1020 && time > 14 || stateno = 1030 && time > 15 || stateno = 1040 && time > 14 || stateno = 1050 && time > 15 || stateno = 1060 && time > 14 || stateno = 1070 && time > 15) && movecontact


;---------------------------------------------------------------------------
; Jump Light Punch
[State -1, Jump Light Punch]
type = ChangeState
value = 600
Triggerall=var(59)=0
triggerall = command = "x"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact

[State -1, Jump Light Punch AI]
type = ChangeState
value = 600
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*0.5
Triggerall=!Inguarddist
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact

;---------------------------------------------------------------------------
; Jump Medium Punch
[State -1, Jump Medium Punch]
type = ChangeState
value = 610
Triggerall=var(59)=0
triggerall = command = "y"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact

[State -1, Jump Medium Punch AI]
type = ChangeState
value = 610
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*0.5
Triggerall=!Inguarddist
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact


;---------------------------------------------------------------------------
; Jump Light Kick
[State -1, Jump Light Kick]
type = ChangeState
value = 630
Triggerall=var(59)=0
triggerall = command = "a"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact

; Jump Light Kick
[State -1, Jump Light Kick AI]
type = ChangeState
value = 630
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*0.5
Triggerall=!Inguarddist
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact

;---------------------------------------------------------------------------
; Jump Medium Kick
[State -1, Jump Medium Kick]
type = ChangeState
value = 640
Triggerall=var(59)=0
triggerall = command = "b"
trigger1 = statetype = A
trigger1 = ctrl
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact

[State -1, Jump Medium Kick AI]
type = ChangeState
value = 640
Triggerall=var(59)>0
triggerall = !Win
Triggerall=random<var(50)*0.5
Triggerall=!Inguarddist
triggerall = P2Bodydist X = [0,20]
triggerall = P2Bodydist Y = [0,25]
triggerall = P2Statetype != L
triggerall = P2Statetype = A
trigger1 = statetype = A
trigger1 = ctrl
Triggerall=AILevel>=1
trigger2 = (stateno = 600 && time > 10 || stateno = 610  && time > 10 || stateno = 630 && time > 10 || stateno = 640 && time > 10) && movecontact
;---------------------------------------------------------------------------
